Signal functions
----------------

The functions in this section describe non-sinusoidal waveforms, which are often used in signal processing and electronics.

Square wave signal
...................................................

:func:`~mpmath.squarew`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: mpmath.squarew(t, amplitude=1, period=1)

Triangle wave signal
...............................

:func:`~mpmath.trianglew`
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: mpmath.trianglew(t, amplitude=1, period=1)

Sawtooth wave signal
......................

:func:`~mpmath.sawtoothw`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: mpmath.sawtoothw(t, amplitude=1, period=1)

Unit triangle signal
.....................

:func:`~mpmath.unit_triangle`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: mpmath.unit_triangle(t, amplitude=1)

Sigmoid wave signal
.....................

:func:`~mpmath.sigmoid`
^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: mpmath.sigmoid(t, amplitude=1)
